==> cfengine3_3.12.1.orig.tar.gz: cfengine-3.12.1/cf-agent/verify_packages.h <==
/*
   Copyright 2018 Northern.tech AS

   This file is part of CFEngine 3 - written and maintained by Northern.tech AS.

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; version 3.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

  To the extent this program is licensed as part of the Enterprise
  versions of CFEngine, the applicable Commercial Open Source License
  (COSL) may apply to this file if you as a licensee so wish it. See
  included file COSL.txt.
*/

#ifndef CFENGINE_VERIFY_PACKAGES_H
#define CFENGINE_VERIFY_PACKAGES_H

#include <cf3.defs.h>

#include <vercmp.h>

PromiseResult VerifyPackagesPromise(EvalContext *ctx, const Promise *pp);
void ExecuteScheduledPackages(EvalContext *ctx);
void CleanScheduledPackages(void);
int PrependPackageItem(EvalContext *ctx, PackageItem **list,
                       const char *name, const char *version,
                       const char *arch, const Promise *pp);

// For testing.
VersionCmpResult ComparePackages(EvalContext *ctx,
                                 const char *n, const char *v, const char *arch,
                                 PackageItem *pi, Attributes a,
                                 const Promise *pp,
                                 const char *mode,
                                 PromiseResult *result);


#endif

==> cfengine3_3.15.2.orig.tar.gz: cfengine-3.15.2/cf-agent/verify_packages.h <==
/*
  Copyright 2019 Northern.tech AS

  This file is part of CFEngine 3 - written and maintained by Northern.tech AS.

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; version 3.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

  To the extent this program is licensed as part of the Enterprise
  versions of CFEngine, the applicable Commercial Open Source License
  (COSL) may apply to this file if you as a licensee so wish it. See
  included file COSL.txt.
*/

#ifndef CFENGINE_VERIFY_PACKAGES_H
#define CFENGINE_VERIFY_PACKAGES_H

#include <cf3.defs.h>

#include <vercmp.h>

PromiseResult VerifyPackagesPromise(EvalContext *ctx, const Promise *pp);
void ExecuteScheduledPackages(EvalContext *ctx);
void CleanScheduledPackages(void);
bool PrependPackageItem(EvalContext *ctx, PackageItem **list,
                       const char *name, const char *version,
                       const char *arch, const Promise *pp);

// For testing.
VersionCmpResult ComparePackages(EvalContext *ctx,
                                 const char *n, const char *v, const char *arch,
                                 PackageItem *pi, const Attributes *a,
                                 const Promise *pp,
                                 const char *mode,
                                 PromiseResult *result);


#endif
